@@ -64,6 +64,9 @@ static void meta_frames_paint_to_drawable (MetaFrames   *frames,
                                            GdkDrawable  *drawable,
                                            GdkRegion    *region);
 
+static void meta_frames_set_window_background (MetaFrames   *frames,
+                                               MetaUIFrame  *frame);
+
 static void meta_frames_calc_geometry (MetaFrames        *frames,
                                        MetaUIFrame         *frame,
                                        MetaFrameGeometry *fgeom);
@@ -270,8 +273,8 @@ queue_recalc_func (gpointer key, gpointer value, gpointer data)
    * resize may not actually be needed so we always redraw
    * in case of color change.
    */
-  gtk_style_set_background (GTK_WIDGET (frames)->style,
-                            frame->window, GTK_STATE_NORMAL);
+  meta_frames_set_window_background (frames, frame);
+  
   gdk_window_invalidate_rect (frame->window, NULL, FALSE);
   meta_core_queue_frame_resize (gdk_display,
                                 frame->xwindow);
@@ -315,8 +318,8 @@ queue_draw_func (gpointer key, gpointer value, gpointer data)
    * resize may not actually be needed so we always redraw
    * in case of color change.
    */
-  gtk_style_set_background (GTK_WIDGET (frames)->style,
-                            frame->window, GTK_STATE_NORMAL);
+  meta_frames_set_window_background (frames, frame);
+
   gdk_window_invalidate_rect (frame->window, NULL, FALSE);
 }
 
@@ -469,6 +472,7 @@ meta_frames_manage_window (MetaFrames *frames,
 			   GdkWindow  *window)
 {
   MetaUIFrame *frame;
+  GdkColor col;
 
   g_assert (window);
 
@@ -477,8 +481,9 @@ meta_frames_manage_window (MetaFrames *frames,
   frame->window = window;
 
   gdk_window_set_user_data (frame->window, frames);
-  gtk_style_set_background (GTK_WIDGET (frames)->style,
-			    frame->window, GTK_STATE_NORMAL);
+
+  /* Set the window background to the current style */
+  meta_frames_set_window_background (frames, frame);
 
   /* Don't set event mask here, it's in frame.c */
   
@@ -612,8 +617,8 @@ meta_frames_reset_bg (MetaFrames *frames,
   widget = GTK_WIDGET (frames);
 
   frame = meta_frames_lookup_window (frames, xwindow);
-  
-  gtk_style_set_background (widget->style, frame->window, GTK_STATE_NORMAL);
+
+  meta_frames_set_window_background (frames, frame);
 }
 
 static void
@@ -1893,6 +1898,22 @@ meta_frames_paint_to_drawable (MetaFrames   *frames,
   g_free (areas);
 }
 
+static void
+meta_frames_set_window_background (MetaFrames   *frames,
+                                   MetaUIFrame  *frame)
+{
+  gtk_style_set_background (GTK_WIDGET (frames)->style,
+                            frame->window, GTK_STATE_NORMAL);
+
+#if 0
+  /* This is what we want for transparent background */
+  {
+    col.pixel = 0;
+    gdk_window_set_background (window, &col);
+  }
+#endif
+}
+
 static gboolean
 meta_frames_enter_notify_event      (GtkWidget           *widget,
                                      GdkEventCrossing    *event)
